/*

Código fonte de exemplo para uso com a Placa Arduino Bricks RTC fabricada pela Zuchi c/ Chipset Microchip MCP74910 

Este código de exemplo é de domínio público

Autor: Pedro Zuchi - pedro@zuchi.com.br
Loja Virtual: www.zuchishop.com.br, www.zuchi.com.br
Área de download: www.zuchi.com.br/download
Blog: www.androidarduino.com.br, www.androidioio.com.br

Observações:
Este exemplo faz uso de uma Placa Arduino Duemilanove e uma Placa Arduino Bricks RTC
Portas da Placa Arduino Duemilanove utilizadas no exemplo:
Sinal SDA - Analog Input 4
Sinal SCL - Analog Input 5

*/

#include <Wire.h>       // Include necessário para dispositivos TWI(I2C)

#define SEGUNDOS 0     // Definição dos indices para leitura dos dados do RTC
#define MINUTOS 1
#define HORAS 2         
#define DIASEMANA 3 
#define DIAMES 4  
#define MES 5 
#define ANO 6 

void setup()
{
  Serial.begin(9600);   // Inicialização da porta serial
  Wire.begin();         // Inicialização do barramento TWI(I2C)
  // Após a colocação da bateria no RTC, é necessário acertar o calendário e o relógio
  // do mesmo para que este comece a operar adequadamente para isto, compile este exemplo
  // uma primeira vez com a linha de código a seguir e carregue-o na placa Duemilanove.
  // Após este procedimento, comente a linha, recompile o programa mais uma vez e
  // recarregue-o na placa Duemilanove.
  mcp74910setup();
}

void loop(){
  DisplayRTCData(2,6);
  Serial.print(":");
  DisplayRTCData(1,7);
  Serial.print(":");
  DisplayRTCData(0,7);
  Serial.print(" ");
  DisplayRTCData(4,6);    
  Serial.print("/");  
  DisplayRTCData(5,5);
  Serial.print("/");
  Serial.print("20");
  DisplayRTCData(6,8);
  Serial.println();   
  delay(1000);
}

unsigned char ReadRTCByte(const unsigned char adr){
  unsigned char data;
  Wire.beginTransmission(0x6f);
  Wire.send(adr);
  Wire.endTransmission();
  Wire.requestFrom(0x6f,1);
  while (Wire.available()) data=Wire.receive();
  return data;
}

void WriteRTCByte(const unsigned char adr, const unsigned char data){
  Wire.beginTransmission(0x6f);
  Wire.send(adr);
  Wire.send(data);
  Wire.endTransmission();
} 

void DisplayRTCData(const unsigned char adr, const unsigned char validbits){
  unsigned char data; 
  data=ReadRTCByte(adr);
  data=data&0xff>>(8-validbits);
  if (data<10) Serial.print("0");
  Serial.print(data,HEX);
}

void mcp74910setup(void) {
  WriteRTCByte(SEGUNDOS,0);  // PARA RTC
  WriteRTCByte(MINUTOS,0x00); // MINUTO=0
  WriteRTCByte(HORAS,0x00); // HORA=0
  WriteRTCByte(DIASEMANA,0x08); // DIA DA SEMANA=0(DOMINGO) E VBAT=1
  WriteRTCByte(DIAMES,0x01); // DIA DO MÊS=1
  WriteRTCByte(MES,0x01); // MÊS=1
  WriteRTCByte(ANO,0x12); // ANO=12
  WriteRTCByte(SEGUNDOS,0x80); // INICIA RTC C/ SEGUNDO=0
  delay(100);  
}

